# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from agatha_protobuf.analysis import analysis_pb2 as agatha__protobuf_dot_analysis_dot_analysis__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in agatha_protobuf/analysis/analysis_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AnalysisServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAnalysis = channel.unary_unary(
                '/analysis.AnalysisService/CreateAnalysis',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
                _registered_method=True)
        self.GetAnalysis = channel.unary_unary(
                '/analysis.AnalysisService/GetAnalysis',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
                _registered_method=True)
        self.ListAnalyses = channel.unary_unary(
                '/analysis.AnalysisService/ListAnalyses',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesResponse.FromString,
                _registered_method=True)
        self.UpdateAnalysis = channel.unary_unary(
                '/analysis.AnalysisService/UpdateAnalysis',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateAnalysisRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
                _registered_method=True)
        self.DeleteAnalysis = channel.unary_unary(
                '/analysis.AnalysisService/DeleteAnalysis',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisResponse.FromString,
                _registered_method=True)
        self.CreateFeedback = channel.unary_unary(
                '/analysis.AnalysisService/CreateFeedback',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
                _registered_method=True)
        self.GetFeedback = channel.unary_unary(
                '/analysis.AnalysisService/GetFeedback',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetFeedbackRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
                _registered_method=True)
        self.ListFeedbacks = channel.unary_unary(
                '/analysis.AnalysisService/ListFeedbacks',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksResponse.FromString,
                _registered_method=True)
        self.UpdateFeedback = channel.unary_unary(
                '/analysis.AnalysisService/UpdateFeedback',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateFeedbackRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
                _registered_method=True)
        self.DeleteFeedback = channel.unary_unary(
                '/analysis.AnalysisService/DeleteFeedback',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackResponse.FromString,
                _registered_method=True)
        self.CreateAnalysisFromLLMS = channel.unary_unary(
                '/analysis.AnalysisService/CreateAnalysisFromLLMS',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSResponse.FromString,
                _registered_method=True)
        self.GetAnalysisFromLLMS = channel.unary_unary(
                '/analysis.AnalysisService/GetAnalysisFromLLMS',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSResponse.FromString,
                _registered_method=True)
        self.CreateMigration = channel.unary_unary(
                '/analysis.AnalysisService/CreateMigration',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMigrationResponse.FromString,
                _registered_method=True)
        self.CreateMoodHistory = channel.unary_unary(
                '/analysis.AnalysisService/CreateMoodHistory',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodHistoryRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.MoodHistory.FromString,
                _registered_method=True)
        self.ListMoodHistory = channel.unary_unary(
                '/analysis.AnalysisService/ListMoodHistory',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryResponse.FromString,
                _registered_method=True)
        self.CreateMood = channel.unary_unary(
                '/analysis.AnalysisService/CreateMood',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
                _registered_method=True)
        self.GetMood = channel.unary_unary(
                '/analysis.AnalysisService/GetMood',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetMoodRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
                _registered_method=True)
        self.UpdateMood = channel.unary_unary(
                '/analysis.AnalysisService/UpdateMood',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateMoodRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
                _registered_method=True)
        self.DeleteMood = channel.unary_unary(
                '/analysis.AnalysisService/DeleteMood',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodResponse.FromString,
                _registered_method=True)
        self.ListMoods = channel.unary_unary(
                '/analysis.AnalysisService/ListMoods',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsResponse.FromString,
                _registered_method=True)


class AnalysisServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAnalysis(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnalysis(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAnalyses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAnalysis(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAnalysis(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeedbacks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAnalysisFromLLMS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnalysisFromLLMS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMigration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMoodHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMoodHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMood(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMood(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMood(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMood(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMoods(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAnalysis': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAnalysis,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.SerializeToString,
            ),
            'GetAnalysis': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAnalysis,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.SerializeToString,
            ),
            'ListAnalyses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAnalyses,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesResponse.SerializeToString,
            ),
            'UpdateAnalysis': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAnalysis,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateAnalysisRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.SerializeToString,
            ),
            'DeleteAnalysis': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAnalysis,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisResponse.SerializeToString,
            ),
            'CreateFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeedback,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.SerializeToString,
            ),
            'GetFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeedback,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetFeedbackRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.SerializeToString,
            ),
            'ListFeedbacks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeedbacks,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksResponse.SerializeToString,
            ),
            'UpdateFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeedback,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateFeedbackRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.SerializeToString,
            ),
            'DeleteFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeedback,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackResponse.SerializeToString,
            ),
            'CreateAnalysisFromLLMS': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAnalysisFromLLMS,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSResponse.SerializeToString,
            ),
            'GetAnalysisFromLLMS': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAnalysisFromLLMS,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSResponse.SerializeToString,
            ),
            'CreateMigration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMigration,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMigrationResponse.SerializeToString,
            ),
            'CreateMoodHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMoodHistory,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodHistoryRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.MoodHistory.SerializeToString,
            ),
            'ListMoodHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMoodHistory,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryResponse.SerializeToString,
            ),
            'CreateMood': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMood,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.SerializeToString,
            ),
            'GetMood': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMood,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.GetMoodRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.SerializeToString,
            ),
            'UpdateMood': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMood,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateMoodRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.SerializeToString,
            ),
            'DeleteMood': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMood,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodResponse.SerializeToString,
            ),
            'ListMoods': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMoods,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'analysis.AnalysisService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('analysis.AnalysisService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AnalysisService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAnalysis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateAnalysis',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAnalysis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/GetAnalysis',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAnalyses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/ListAnalyses',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListAnalysesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAnalysis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/UpdateAnalysis',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateAnalysisRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Analysis.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteAnalysis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/DeleteAnalysis',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteAnalysisResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateFeedback',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/GetFeedback',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.GetFeedbackRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListFeedbacks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/ListFeedbacks',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListFeedbacksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/UpdateFeedback',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateFeedbackRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Feedback.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/DeleteFeedback',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteFeedbackResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAnalysisFromLLMS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateAnalysisFromLLMS',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateAnalysisFromLLMSResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAnalysisFromLLMS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/GetAnalysisFromLLMS',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.GetAnalysisFromLLMSResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMigration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateMigration',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMigrationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMoodHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateMoodHistory',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodHistoryRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.MoodHistory.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMoodHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/ListMoodHistory',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMood(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateMood',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateMoodRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMood(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/GetMood',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.GetMoodRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateMood(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/UpdateMood',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.UpdateMoodRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.Mood.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteMood(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/DeleteMood',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.DeleteMoodResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMoods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/ListMoods',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.ListMoodsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
